.. craft store documentation root file

=======================================
Welcome to Craft Store's documentation!
=======================================

.. toctree::
   :maxdepth: 1
   :hidden:

   tutorials/index
   howto/index
   reference/index
   explanation/index


.. toctree::
   :caption: About the project

   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
